@@ -33,7 +33,7 @@
 #' multi-core process. When a user has a dataset organized into several files, it applies the
 #' user-defined function to the entire catalog by automatically splitting it into several
 #' clusters. The clustering pattern can be either split into a set of squared areas or split by
-#' file. The clustering pattern can be modified using the global catalog options with \link{catalog_options}.
+#' file. The clustering pattern can be modified using the catalog options (see \link{catalog}.
 #' The "Examples" section describes the procedure for applying functions to the catalog, beginning
 #' with data loading (see example). \cr\cr
 #' \strong{Warning:} there is a mechanism to load buffered data and to avoid edge artifacts,
@@ -73,10 +73,12 @@
 #' project = catalog(LASfile)
 #' plot(project)
 #'
-#' # 2. Set some global catalog options
+#' # 2. Set some catalog options
 #' # For this dummy example, the clustering size is 80 m and the buffer is 15 m using
 #' # a single core (because this example is run on the CRAN server when the package is submitted).
-#' catalog_options(buffer = 15, multicore = 1, tiling_size = 120)
+#' buffer(project) = 15
+#' cores(project) = 1
+#' tiling_size(project) = 120
 #'
 #' # 3. Load the shapefile needed to filter your points.
 #' folder <- system.file("extdata", "", package="lidR")
@@ -94,14 +96,14 @@
 #'   lasclassify(las, lake, field = "lake")
 #'
 #'   # filter lakes, and low elevation points
-#'   las %<>% lasfilter(lake == FALSE, Z > 4)
+#'   las = lasfilter(las, lake == FALSE, Z > 4)
 #'
 #'   if (is.null(las))
 #'     return(NULL)
 #'
 #'   # segment trees (in this example the low point density does not enable
 #'   # accurate segmentation of trees. This is just a proof-of-concept)
-#'   lastrees(las, algorithm = "li2012")
+#'   lastrees(las, algorithm = "li2012-2")
 #'
 #'   # Here we used the function tree_metric to compute some metrics for each tree. This
 #'   # function is defined later in the global environment.
@@ -157,35 +159,28 @@
 #' # of the list is a data.table, so rbindlist does the job:
 #' output = data.table::rbindlist(output)
 #'
-#' output %$% plot(x,y, cex = sqrt(area/pi)/5, asp = 1)
+#' with(output, plot(x,y, cex = sqrt(area/pi)/5, asp = 1))
 #' @export
 catalog_apply <- function(ctg, func, func_args = NULL, ...)
 {
-  progress  = CATALOGOPTIONS("progress")
-  ncores   <- CATALOGOPTIONS("multicore")
-  buffer   <- CATALOGOPTIONS("buffer")
-  by_file  <- CATALOGOPTIONS("by_file")
-  res      <- 1
+  res       <- 1
+  progress  <- progress(ctg)
+  ncores    <- cores(ctg)
 
-  clusters <- catalog_makecluster(ctg, res, buffer, by_file)
-
-  nclust = length(clusters)
+  clusters <- catalog_makecluster(ctg, res)
+  nclust   <- length(clusters)
 
   if (nclust < ncores)
     ncores <- nclust
 
-  if (ncores > 1)
-    future::plan(future::multiprocess, workers = ncores)
-  else
-    future::plan(future::sequential)
+  future::plan(future::multiprocess, workers = ncores)
 
   output = list()
-
   for(i in seq_along(clusters))
   {
     cluster = clusters[[i]]
 
-    output[[i]] <- future::future({cluster_apply_func(cluster, func, ctg, func_args, ...) })
+    output[[i]] <- future::future({cluster_apply_func(cluster, func, ctg, func_args, ...) }, earlySignal = TRUE)
 
     if(progress)
     {
