@@ -126,11 +126,12 @@ lasnormalize = function(las, dtm = NULL, method, k = 10L, p = 1, model = gstat::
     if(!is(dtm, "RasterLayer"))
       stop("The terrain model is not a RasterLayer or a lasmetrics", call. = F)
 
-    xres = raster::res(dtm)[1]
-    xmin = dtm@extent@xmin
-    ymin = dtm@extent@ymin
-    dtm  = raster::as.matrix(dtm)
-    Zground = fast_extract(dtm, las@data$X, las@data$Y, xmin, ymin, xres) # 15 times faster than raster::extract + much memory effcient
+    #xres = raster::res(dtm)[1]
+    #xmin = dtm@extent@xmin
+    #ymin = dtm@extent@ymin
+    #dtm  = raster::as.matrix(dtm)
+    #Zground = fast_extract(dtm, las@data$X, las@data$Y, xmin, ymin, xres) # 15 times faster than raster::extract + much memory effcient
+    Zground = raster::extract(dtm, las@data[, .(X,Y)])
 
     isna = is.na(Zground)
     nnas = sum(isna)
@@ -141,11 +142,11 @@ lasnormalize = function(las, dtm = NULL, method, k = 10L, p = 1, model = gstat::
 
   if (!copy)
   {
-    las@data[, Zref := Z]
+    if (!"Zref" %in% names(las@data))
+      las@data[, Zref := Z]
+
     las@data[, Z := round(Z - Zground, 3)]
-    las@data[]
-    update_list_by_ref(las@header@PHB, "Min Z", min(las@data$Z))
-    update_list_by_ref(las@header@PHB, "Max Z", max(las@data$Z))
+    lasupdateheader(las)
     lascheck(las@data, las@header)
     return(invisible())
   }
@@ -163,12 +164,14 @@ lasunnormalize = function(las)
 {
   Z <- Zref <- NULL
 
-  if (! "Zref" %in% names(las@data))
-    stop("No field 'Zref' found.", call. = FALSE)
-
-  las@data[, Z := Zref]
-  las@data[, Zref := NULL]
-  las@data[]
+  if ("Zref" %in% names(las@data))
+  {
+    las@data[, Z := Zref]
+    las@data[, Zref := NULL]
+    las@data[]
+  }
+  else
+    message("No field 'Zref' found. Unormalizisation is impossible", call. = FALSE)
 
   return(invisible())
 }
