@@ -1,10 +1,14 @@
 context("casting")
 
-library(raster)
+#sink(tempfile())
+
+#library(raster)
 LASfile <- system.file("extdata", "Megaplot.laz", package = "lidR")
 las = readLAS(LASfile)
 lasflightline(las)
 
+#sink(NULL)
+
 test_that("as.raster return a correct raster layer (simple case)", {
 
   out = grid_metrics(las, max(Z))
@@ -12,14 +16,14 @@ test_that("as.raster return a correct raster layer (simple case)", {
 
   expect_true(is(out, "RasterLayer"))
   expect_equal(dim(out), c(13, 12, 1))
-  expect_equal(res(out), c(20, 20))
+  expect_equal(raster::res(out), c(20, 20))
 
   out = grid_metrics(las, max(Z), 10)
   out = as.raster(out)
 
   expect_true(is(out, "RasterLayer"))
   expect_equal(dim(out), c(24, 24, 1))
-  expect_equal(res(out), c(10, 10))
+  expect_equal(raster::res(out), c(10, 10))
 })
 
 test_that("as.raster return a correct raster stack (simple case)", {
@@ -30,7 +34,7 @@ test_that("as.raster return a correct raster stack (simple case)", {
 
   expect_true(is(out, "RasterStack"))
   expect_equal(dim(out), c(13, 12, depth))
-  expect_equal(res(out), c(20, 20))
+  expect_equal(raster::res(out), c(20, 20))
 
   out = grid_metrics(las, .stdmetrics_z, 10)
   depth = ncol(out) - 2
@@ -38,7 +42,7 @@ test_that("as.raster return a correct raster stack (simple case)", {
 
   expect_true(is(out, "RasterStack"))
   expect_equal(dim(out), c(24, 24, depth))
-  expect_equal(res(out), c(10, 10))
+  expect_equal(raster::res(out), c(10, 10))
 })
 
 
@@ -51,7 +55,7 @@ test_that("as.raster return a correct raster layer (tricky case)", {
 
   expect_true(is(out, "RasterLayer"))
   expect_equal(dim(out), c(13, 12, 1))
-  expect_equal(res(out), c(20, 20))
+  expect_equal(raster::res(out), c(20, 20))
 
   out = grid_metrics(las, max(Z), 10)
   out = out[(X < 684830 | X > 684900) & (Y < 5017900 | Y > 5017940)]
@@ -60,7 +64,7 @@ test_that("as.raster return a correct raster layer (tricky case)", {
 
   expect_true(is(out, "RasterLayer"))
   expect_equal(dim(out), c(24, 24, 1))
-  expect_equal(res(out), c(10, 10))
+  expect_equal(raster::res(out), c(10, 10))
 })
 
 test_that("as.raster return a correct raster stack (tricky case)", {
@@ -73,7 +77,7 @@ test_that("as.raster return a correct raster stack (tricky case)", {
 
   expect_true(is(out, "RasterStack"))
   expect_equal(dim(out), c(24, 24, depth))
-  expect_equal(res(out), c(10, 10))
+  expect_equal(raster::res(out), c(10, 10))
 })
 
 test_that("as.raster return a correct raster stack (simple case)", {
@@ -84,7 +88,7 @@ test_that("as.raster return a correct raster stack (simple case)", {
 
   expect_true(is(out, "RasterStack"))
   expect_equal(dim(out), c(13, 12, depth))
-  expect_equal(res(out), c(20, 20))
+  expect_equal(raster::res(out), c(20, 20))
 
   out = grid_metrics(las, .stdmetrics_z, 10)
   depth = ncol(out) - 2
@@ -92,7 +96,7 @@ test_that("as.raster return a correct raster stack (simple case)", {
 
   expect_true(is(out, "RasterStack"))
   expect_equal(dim(out), c(24, 24, depth))
-  expect_equal(res(out), c(10, 10))
+  expect_equal(raster::res(out), c(10, 10))
 })
 
 test_that("as.raster return a correct raster layer with duplicated entries", {
@@ -102,7 +106,7 @@ test_that("as.raster return a correct raster layer with duplicated entries", {
 
   expect_true(is(out, "RasterLayer"))
   expect_equal(dim(out), c(13, 12, 1))
-  expect_equal(res(out), c(20, 20))
+  expect_equal(raster::res(out), c(20, 20))
 })
 
 test_that("as.raster return the same output both with dcast and sp", {
@@ -119,11 +123,11 @@ test_that("as.raster guess the resolution properly", {
   out = out[ X < 684800 | X > 684900]
   out = as.raster(out)
 
-  expect_equal(res(out), c(20, 20))
+  expect_equal(raster::res(out), c(20, 20))
 
   out = grid_metrics(las, max(Z), 10)
   out = out[(X < 684830 | X > 684900) & (Y < 5017900 | Y > 5017940)]
   out = as.raster(out)
 
-  expect_equal(res(out), c(10, 10))
+  expect_equal(raster::res(out), c(10, 10))
 })
